@@ -40,6 +40,7 @@ class MountPoint(object):
         'debugfs',
         'configfs',
         'fusectl',
+        'rpc_pipefs',
     )
 
     @classmethod
@@ -391,6 +392,29 @@ class Filesystems(object):
             raise FilesystemException("error while formation %s. STDOUT: %s STDERR: %s CMD: %s" % (device, out.stdout, out.stderr, mkfs))
 
 
+    def deleteFsByUuid(self, uuid):
+        fs = self.getByUUUID(uuid)
+        if fs == None:
+            return True
+        fstabFile = os.path.join('/','etc','fstab')
+        newFstab = []
+        for line in readfileAsArray(fstabFile):
+            if line.startswith('#'):
+                newFstab.append(line)
+            else:
+                t = MountPoint.parseFstabStrin(line)
+                if t != fs:
+                    newFstab.append(line)
+        writefileFromArray(fstabFile, newFstab)
+        self.refresh()
+        f2 = self.getByUUUID(uuid)
+        if f2 == None:
+            return True
+        elif fs.mountpoint != f2.mountpoint:
+            return True
+        return '%s - %s' % (fs.mountpoint , f2.mountpoint)
+
+
     @classmethod
     def getUuid(cls, dev, generate=True):
         """
@@ -418,7 +442,7 @@ class Filesystems(object):
                 if m and len(m.groups()) == 2:
                     cls._UUID[m.group(1)] = m.group(2)
         if generate:
-            id = cls.mc.get("sdf")
+            id = cls.mc.get(dev)
             if id == None:
                 id = str(uuid.uuid3(uuid.NAMESPACE_DNS, 'exon-api-fs'))
                 cls.mc.set(dev, id)
